wot.grn package
===============

Submodules
----------

wot.grn.sparse\_optimization module
-----------------------------------

.. automodule:: wot.grn.sparse_optimization
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: wot.grn
    :members:
    :undoc-members:
    :show-inheritance:
